
library(shiny)
library(markdown)
library(ggmap)
library(shinydashboard)
#library(shinyIncubator)
# RENDER EQUILIBRIUM USER INTERFACE
# renderBanner <- function() # probably won't need this function for the banners - KPJ
# {
#   wellPanel(
#     # Logo image
#     column(9),
#     column(3,
#            img(src="iphclogo.png",  height = 80, width = 80),
#            img(src="iscamLogo.png", height = 80, width = 80)
#     )
#   )
# }

# ----------------------------------------#
# MAIN USER INTERFACE FOR THE APPLICATION #
# ----------------------------------------#

defaultVals<-c(0.1,.1,.3,.5,.5)

dashboardPage(
  skin="black",
  dashboardHeader(title = "Size model Simulator"),
  dashboardSidebar(
    width=170,
    sidebarMenu(
      menuItem("About", tabName = "about"),
      menuItem("Growth and M", tabName = "growthm"),
      menuItem("Fishing", tabName = "fishing"),
      menuItem("Yield functions", tabName = "yield"),
      menuItem("Projections", tabName = "projections"),
      menuItem("Technical Description", tabName = "technical"),
      menuItem("The Developers", tabName = "developers"),
      menuItem("Glossary", tabName = "glossary")
    )
  ),
  
  dashboardBody(
    
    tabItems(
      tabItem(tabName="about",
              fluidRow(
                tabBox(
                  width=12,
                  status="success",
                  id="About",
                  tabPanel("Introduction",
                           includeMarkdown("www/about.md")),
                  tabPanel("Behavior of size-structured models",
                           includeMarkdown("www/behavior.md")),
                  tabPanel("Yield functions",
                           includeMarkdown("www/yield.md")),
                  tabPanel("Projections",
                           includeMarkdown("www/project.md"))
                )
              )
      ),
      
      
      tabItem(tabName="growthm",
              fixedRow(
                box(
                  width=3,
                  title="Growth parameters",
                  status="success",
                  div(helpText("(mouse over for description)"), style = "font-size:100%"),
                  tags$div(title="Growth increment for animals in the 1st size-class",
                           sliderInput("GrowInc1","1st growth increment",min=1,max=50,value=15,step=1), style = "font-size:80%"),
                  tags$div(title="Growth increment for animals in the 2nd last size-class",
                           sliderInput("GrowInc2","2nd growth increment",min=0.01,max=50,value=5,step=1), style = "font-size:80%"),
                  tags$div(title="Molt probability for animals in the 1st size-class",
                           sliderInput("Molt1","1st molt probability",min=0.01,max=0.99,value=0.9,step=0.01), style = "font-size:80%"),
                  tags$div(title="Molt probability for animalss in the 2nd last size-class",
                           sliderInput("Molt2","2nd molt probability",min=0.01,max=0.99,value=0.5,step=0.01), style = "font-size:80%"),
                  tags$div(title="CV of the growth increment",
                           sliderInput("SigmaL","CV for growth incerement",min=0,max=1,value=0.5,step=0.01), style = "font-size:80%"),
                  br(),
                  tags$div(title="Length-weight exponent",
                           sliderInput("LWE","length-weight exponent",min=2,max=4,value=3,step=0.01), style = "font-size:80%"),
                  tags$div(title="Length-at-maturity",
                           sliderInput("Lmat","Length-at-maturity",min=80,max=180,value=120,step=1), style = "font-size:80%"),
                  br(),
                  tags$div(title="Rate of natural mortality",
                           sliderInput("Mval","Natural mortality",min=0.05,max=0.4,value=0.1,step=0.01), style = "font-size:80%")),
                box(
                  width=9,
                  height=650,
                  align="center",
                  plotOutput("ParDisiplay1"))
              )),
      
      tabItem(tabName="fishing",
              fixedRow(
                box(
                  width=3,
                  title="Selectivity and retention parameters",
                  status="success",
                  div(helpText("(mouse over for description)"), style = "font-size:100%"),
                  tags$div(title="Length-at-50%-selectivity",
                           sliderInput("Sel50","Length-at-50%-selectivity",min=0,max=200,value=130,step=0.01), style = "font-size:80%"),
                  tags$div(title="Width of the selectivity ogive",
                           sliderInput("Delta","Width of the selectivity ogive",min=10,max=100,value=0.5,step=1), style = "font-size:80%"),
                  tags$div(title="Length-at-50%-retetion",
                           sliderInput("Ret50","Length-at-50%-retention",min=0,max=200,value=150,step=0.01), style = "font-size:80%"),
                  tags$div(title="Width of the retention ogive",
                           sliderInput("Delta2","Width of the retention ogive",min=5,max=100,value=0.5,step=1), style = "font-size:80%"),
                  br(),
                  tags$div(title="Fully-selected natural mortality",
                           sliderInput("Fval","Fishing mortality",min=0.00,max=3,value=0.1,step=0.01), style = "font-size:80%")),
                box(
                  width=9,
                  height=650,
                  align="center",
                  plotOutput("ParDisiplay2"))
              )),
      
      tabItem(tabName="yield",
              fluidRow(
                box(
                  width=3,
                  title="Parameters related to yield functions",
                  status="success",
                  div(helpText("(mouse over for description)"), style = "font-size:100%"),
                  tags$div(title="Maximum fishing mortality",
                           sliderInput("Fmax","Maximum fishing mortality",min=0,max=10,value=5,step=0.01), style = "font-size:80%"),
                  tags$div(title="Stock-recruitment steepness",
                           sliderInput("Steep","Steepness",min=0.21,max=1,value=0.9,step=0.01), style = "font-size:80%")),
                box(
                  width=9,
                  height=650,
                  align="center",
                  plotOutput("ParDisiplay3"))
              )),
      
      tabItem(tabName="projections",
              fluidRow(
                column(width=3,
                       box(
                         title="Parameters related to conducting projections",
                         status="success",
                         width=NULL,
                         div(helpText("(mouse over for description)"), style = "font-size:100%"),
                         tags$div(title="Sets basis for calculating future catch limits",
                                  radioButtons("HCR.type", "Type of harvest control rule:",
                                               c("Threshold" = "thresh","Constant Exploitation Rate" = "constE")), style = "font-size:80%"),
                         tags$div(title="Sets the SPR corresponding to a constant exploitaton rate",
                                  numericInput("HCR.expl","Target Exploitation Rate (SPR)",min=0,max=1,value=0.35,step=0.05), style = "font-size:80%"),
                         tags$div(title="Sets the proporiton of BMSY over which exploitation rate changes",
                                  sliderInput("HCR.range", "Range over which exploitation rate changes",min = 0.1, max = 1, value = c(0.1,0.5),step=0.01), style = "font-size:80%"),
                         br(),
                         tags$div(title="Initial Depletion",
                                  sliderInput("Init.Depl","Initial Depletion", min = 0.05, max = 1, value = 0.5,step=0.01), style = "font-size:80%"),
                         br()
                       ),
                       # div(helpText("======================"), style = "font-size:100%"),
                       box(
                         width=NULL,
                         title="Recruitment Parameters",
                         status="success",
                         tags$div(title="Extent of variation in recruitment",
                                  sliderInput("SigmaR","Variation in recruitment", min = 0.05, max = 1, value = 0.6,step=0.01), style = "font-size:80%"),
                         tags$div(title="Extent of variation in recruitment",
                                  sliderInput("ProwR","Correlation in recruitment", min = -1, max = 1, value = 0.0,step=0.01), style = "font-size:80%"),
                         tags$div(title="Extent of variation in recruitment",
                                  sliderInput("SigmaB","Variation in biomass estimation error", min = 0.05, max = 1, value = 0.2,step=0.01), style = "font-size:80%"),
                         tags$div(title="Extent of variation in recruitment",
                                  sliderInput("ProwB","Correlation in biomass estimation error", min = -1, max = 1, value = 0.0,step=0.01), style = "font-size:80%")
                       )
                ),
                box(
                  width=9,
                  height=650,
                  align="center",
                  plotOutput("ParDisiplay4"))
                
              )),
      
      tabItem(tabName="technical",
              fluidRow(
                tabBox(
                  width=12,
                  status="success",
                  tabPanel("Introduction",
                           includeMarkdown("www/techdescript.md")),
                  tabPanel("Population Dynamics",
                           includeMarkdown("www/basicmodel.md")),
                  tabPanel("Equilibrium Size-structure",
                           includeMarkdown("www/equilibriumss.md")),
                  tabPanel("Projecting",
                           includeMarkdown("www/projections.md")),
                  tabPanel("Parameterization",
                           includeMarkdown("www/parameters.md"))
                )
              )),
      
      tabItem(tabName="developers",
              fluidRow(
                box(
                  status="success",
                  width=12,
                  includeMarkdown("www/about2.md")) #add a comma here if uncomment box below
                #           box(
                #           plotOutput("NULLS2"))
                
              )
      ),
      
      tabItem(tabName="glossary",
              fluidRow(
                box(
                  status="success",
                  width=12,
                  tableOutput("glossary")
                  
                )
              )
      )
    )
  )
)


